==> cv-react-library-0.1.12.tgz: package/src/components/web/DateTimePicker/DateTimePicker.styles.js <==
// Core component styles
const coreStyles = {
    container: {
    },

    inputContainer: {
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        paddingHorizontal: 13,
        paddingVertical: 6,

        // Themed
        borderWidth: 1,
        borderStyle: 'solid',
        borderColor: '#006e96',
        borderRadius: 6,
    },

    inputText: {
    },

    iconContainer: {
    },

    icon: {
        paddingLeft: 5,
    },

    pickerToolbar: {
    },

    pickerTabs: {

    },

    pickerModalDialog: {
    },

    pickerModalDialogAction: {
    },

    calenderHeader: {
    },

    calenderDay: {
    },

    calenderDayIsSelected: {
    },

    clockContainer: {
    },

    clock: {
    },

    clockPin: {
    },

    clockPointer: {
    },

    clockThumb: {
    },

    clockNoPoint: {
    },

    clockNumber: {
    },

    clockNumberSelected: {
    },
};

/**
 * Helper method to get styles for this component
 * @param {Object} contextStyles - Styles for this component
 */
const getStyles = (contextStyles = {}) => {
    return {
        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },

        inputContainer: {
            ...coreStyles.inputContainer,
            ...contextStyles.inputContainer,
        },

        inputText: {
            ...coreStyles.inputText,
            ...contextStyles.inputText,
        },

        iconContainer: {
            ...coreStyles.iconContainer,
            ...contextStyles.iconContainer,
        },

        icon: {
            ...coreStyles.icon,
            ...contextStyles.icon,
        },

        pickerToolbar: {
            ...coreStyles.pickerToolbar,
            ...contextStyles.pickerToolbar,
        },

        pickerTabs: {
            ...coreStyles.pickerTabs,
            ...contextStyles.pickerTabs,
        },

        pickerModal: {
            ...coreStyles.pickerModal,
            ...contextStyles.pickerModal,
        },

        pickerModalDialogAction: {
            ...coreStyles.pickerModalDialogAction,
            ...contextStyles.pickerModalDialogAction,
        },

        calenderHeader: {
            ...coreStyles.calenderHeader,
            ...contextStyles.calenderHeader,
        },

        calenderDay: {
            ...coreStyles.calenderDay,
            ...contextStyles.calenderDay,
        },

        calenderDayIsSelected: {
            ...coreStyles.calenderDayIsSelected,
            ...contextStyles.calenderDayIsSelected,
        },

        clockContainer: {
            ...coreStyles.clockContainer,
            ...contextStyles.clockContainer,
        },

        clock: {
            ...coreStyles.clock,
            ...contextStyles.clock,
        },

        clockPin: {
            ...coreStyles.clockPin,
            ...contextStyles.clockPin,
        },

        clockPointer: {
            ...coreStyles.clockPointer,
            ...contextStyles.clockPointer,
        },

        clockThumb: {
            ...coreStyles.clockThumb,
            ...contextStyles.clockThumb,
        },

        clockNoPoint: {
            ...coreStyles.clockNoPoint,
            ...contextStyles.clockNoPoint,
        },

        clockNumber: {
            ...coreStyles.clockNumber,
            ...contextStyles.clockNumber,
        },

        clockNumberSelected: {
            ...coreStyles.clockNumberSelected,
            ...contextStyles.clockNumberSelected,
        },
    };
};

export default getStyles;

==> cv-react-library-0.1.29.tgz: package/src/components/web/DateTimePicker/DateTimePicker.styles.js <==
// Core component styles
const coreStyles = {
    container: {
    },

    inputContainer: {
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        paddingHorizontal: 13,
        paddingVertical: 6,

        // Themed
        borderWidth: 1,
        borderStyle: 'solid',
        borderColor: '#006e96',
        borderRadius: 6,
    },

    inputText: {
    },

    iconContainer: {
    },

    icon: {
        paddingLeft: 5,
    },

    pickerToolbar: {
    },

    pickerTabs: {

    },

    pickerModalDialog: {
    },

    pickerModalDialogAction: {
    },

    calenderHeader: {
    },

    calenderDay: {
    },

    calenderDayIsSelected: {
    },

    clockContainer: {
    },

    clock: {
    },

    clockPin: {
    },

    clockPointer: {
    },

    clockThumb: {
    },

    clockNoPoint: {
    },

    clockNumber: {
    },

    clockNumberSelected: {
    },
};

/**
 * Helper method to get styles for this component
 * @param {Object} contextStyles - Styles for this component
 */
const getStyles = (contextStyles = {}) => {
    return {
        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },

        inputContainer: {
            ...coreStyles.inputContainer,
            ...contextStyles.inputContainer,
        },

        inputText: {
            ...coreStyles.inputText,
            ...contextStyles.inputText,
        },

        iconContainer: {
            ...coreStyles.iconContainer,
            ...contextStyles.iconContainer,
        },

        icon: {
            ...coreStyles.icon,
            ...contextStyles.icon,
        },

        pickerToolbar: {
            ...coreStyles.pickerToolbar,
            ...contextStyles.pickerToolbar,
        },

        pickerTabs: {
            ...coreStyles.pickerTabs,
            ...contextStyles.pickerTabs,
        },

        pickerModalDialog: {
            ...coreStyles.pickerModalDialog,
            ...contextStyles.pickerModalDialog,
        },

        pickerModalDialogAction: {
            ...coreStyles.pickerModalDialogAction,
            ...contextStyles.pickerModalDialogAction,
        },

        calenderHeader: {
            ...coreStyles.calenderHeader,
            ...contextStyles.calenderHeader,
        },

        calenderDay: {
            ...coreStyles.calenderDay,
            ...contextStyles.calenderDay,
        },

        calenderDayIsSelected: {
            ...coreStyles.calenderDayIsSelected,
            ...contextStyles.calenderDayIsSelected,
        },

        clockContainer: {
            ...coreStyles.clockContainer,
            ...contextStyles.clockContainer,
        },

        clock: {
            ...coreStyles.clock,
            ...contextStyles.clock,
        },

        clockPin: {
            ...coreStyles.clockPin,
            ...contextStyles.clockPin,
        },

        clockPointer: {
            ...coreStyles.clockPointer,
            ...contextStyles.clockPointer,
        },

        clockThumb: {
            ...coreStyles.clockThumb,
            ...contextStyles.clockThumb,
        },

        clockNoPoint: {
            ...coreStyles.clockNoPoint,
            ...contextStyles.clockNoPoint,
        },

        clockNumber: {
            ...coreStyles.clockNumber,
            ...contextStyles.clockNumber,
        },

        clockNumberSelected: {
            ...coreStyles.clockNumberSelected,
            ...contextStyles.clockNumberSelected,
        },
    };
};

export default getStyles;
